@@ -19,6 +19,10 @@ class SocketClient(object):
             self.pools[addr] = ConnectionPool(host, port, max_conn)
         self.pools[addr].start_connections(num, cb, args, timeout)
 
+#    def free_connection(self, conn):
+#        conn.__start()
+#        self.pools[conn.addr].connection_available(conn)
+
 #    def connect(self,hostname,port,cb=None):
 #        s = io.client_socket(hostname,port)
 #        conn = Connection((hostname,port), s)
@@ -103,7 +107,7 @@ class ConnectionPool(object):
         self.__service_queue()
 
     def __timed_out(self, i):
-        cb, args, timer - self.wait_timers(i)
+        cb, args, timer = self.wait_timers[i]
         timer.delete()
         del self.wait_timers[i]
         self.wait_queue.remove(i)
